==> paycenter-client-3.4.18-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/xib/charge/XibChargeRequestDTO.java <==
package cn.com.duiba.paycenter.dto.payment.charge.xib.charge;

import cn.com.duiba.paycenter.dto.payment.charge.BaseChargeRequest;

import java.util.Date;


/**
 * 厦门国际银行 api请求dto
 *
 * @author zouwx
 * @date 2022/10/24
 */
public class XibChargeRequestDTO extends BaseChargeRequest {

    private static final long serialVersionUID = 3142750966840241409L;

    /**
     * 订单总金额
     */
    private Long txnAmt;

    /**
     * ip地址
     */
    private String ip;

    /**
     * 商品描述
     */
    private String goodsDesc;

    /**
     * 订单描述
     */
    private String orderDesc;

    /**
     * 回调地址
     */
    private String notifyUrl;

    /**
     * 订单结束时间
     */
    private Date scanTime;

    /**
     * 应用关键
     */
    private String appKey;

    /**
     * 调用RemoteAppService.getSimpleApp获取的对象可得到此变量
     */
    private String appSecret;

    /**
     * uid
     */
    private String uid;

    /**
     * 主订单生成日期
     */
    private Date merDate;

    public Date getMerDate() {
        return merDate;
    }

    public void setMerDate(Date merDate) {
        this.merDate = merDate;
    }

    public Long getTxnAmt() {
        return txnAmt;
    }

    public void setTxnAmt(Long txnAmt) {
        this.txnAmt = txnAmt;
    }

    public String getNotifyUrl() {
        return notifyUrl;
    }

    public void setNotifyUrl(String notifyUrl) {
        this.notifyUrl = notifyUrl;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getOrderDesc() {
        return orderDesc;
    }

    public void setOrderDesc(String orderDesc) {
        this.orderDesc = orderDesc;
    }

    public String getGoodsDesc() {
        return goodsDesc;
    }

    public void setGoodsDesc(String goodsDesc) {
        this.goodsDesc = goodsDesc;
    }

    public Date getScanTime() {
        return scanTime;
    }

    public void setScanTime(Date scanTime) {
        this.scanTime = scanTime;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public String getAppSecret() {
        return appSecret;
    }

    public void setAppSecret(String appSecret) {
        this.appSecret = appSecret;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }
}

==> paycenter-client-3.5.12-20240513.020536-4-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/xib/charge/XibChargeRequestDTO.java <==
package cn.com.duiba.paycenter.dto.payment.charge.xib.charge;

import cn.com.duiba.paycenter.dto.payment.charge.BaseChargeRequest;

import java.util.Date;


/**
 * 厦门国际银行 api请求dto
 *
 * @author zouwx
 * @date 2022/10/24
 */
public class XibChargeRequestDTO extends BaseChargeRequest {

    private static final long serialVersionUID = 3142750966840241409L;

    /**
     * 订单总金额
     */
    private Long txnAmt;

    /**
     * ip地址
     */
    private String ip;

    /**
     * 商品描述
     */
    private String goodsDesc;

    /**
     * 订单描述
     */
    private String orderDesc;

    /**
     * 回调地址
     */
    private String notifyUrl;

    /**
     * 下单时间
     */
    private Date orderTime;

    /**
     * 订单结束时间
     */
    private Date scanTime;

    /**
     * 应用关键
     */
    private String appKey;

    /**
     * 调用RemoteAppService.getSimpleApp获取的对象可得到此变量
     */
    private String appSecret;

    /**
     * 跳转地址
     */
    private String redirect;

    /**
     * uid
     */
    private String uid;

    /**
     * 主订单生成日期
     */
    private Date merDate;

    public Date getMerDate() {
        return merDate;
    }

    public void setMerDate(Date merDate) {
        this.merDate = merDate;
    }

    public Long getTxnAmt() {
        return txnAmt;
    }

    public void setTxnAmt(Long txnAmt) {
        this.txnAmt = txnAmt;
    }

    public String getNotifyUrl() {
        return notifyUrl;
    }

    public void setNotifyUrl(String notifyUrl) {
        this.notifyUrl = notifyUrl;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getOrderDesc() {
        return orderDesc;
    }

    public void setOrderDesc(String orderDesc) {
        this.orderDesc = orderDesc;
    }

    public String getGoodsDesc() {
        return goodsDesc;
    }

    public void setGoodsDesc(String goodsDesc) {
        this.goodsDesc = goodsDesc;
    }

    public Date getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(Date orderTime) {
        this.orderTime = orderTime;
    }

    public Date getScanTime() {
        return scanTime;
    }

    public void setScanTime(Date scanTime) {
        this.scanTime = scanTime;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public String getAppSecret() {
        return appSecret;
    }

    public void setAppSecret(String appSecret) {
        this.appSecret = appSecret;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public String getRedirect() {
        return redirect;
    }

    public void setRedirect(String redirect) {
        this.redirect = redirect;
    }
}
